#[repr(u32)]pub enum ColorSpace {
Invalid = 0,
Srgb = 1,
Rec601Ntsc = 2,
Rec601NtscFullRange = 3,
Rec601Pal = 4,
Rec601PalFullRange = 5,
Rec709 = 6,
Rec2020 = 7,
Rec2100 = 8,
Passthrough = 9,
DoNotCare = 4_294_967_294,
UnknownOrdinal_(u32),
}Expand description
Expresses the color space used to interpret video pixel values.
This list has a separate entry for each variant of a color space standard.
For this reason, should we ever add support for the RGB variant of 709, for example, we’d add a separate entry to this list for that variant. Similarly for the RGB variants of 2020 or 2100. Similarly for the YcCbcCrc variant of 2020. Similarly for the ICtCp variant of 2100.
See ImageFormatIsSupportedColorSpaceForPixelFormat() for whether a
combination of PixelFormat and ColorSpace is potentially supported.
Generally, a ColorSpace is not supported for any PixelFormat whose
bits-per-sample isn’t compatible with the color space’s spec, nor for any
PixelFormat which is a mismatch in terms of RGB vs. YUV.
The “limited range” in comments below refers to where black and white are defined to be (and simimlar for chroma), but should not be interpreted as guaranteeing that there won’t be values outside the nominal “limited range”. In other words, “limited range” doesn’t necessarily mean there won’t be any values below black or above white, or outside the “limited” chroma range. For “full range”, black is 0 and white is the max possible/permitted numeric value (and similar for chroma).
Variants
Invalid = 0
Srgb = 1
Rec601Ntsc = 2
Rec601NtscFullRange = 3
Rec601Pal = 4
Rec601PalFullRange = 5
Rec709 = 6
Rec2020 = 7
Rec2100 = 8
Passthrough = 9
DoNotCare = 4_294_967_294
UnknownOrdinal_(u32)